/**
 * @file Run apeman-task-contrib-mkdir
 */

"use strict";

var async = require('async'),
    mkdirp = require('mkdirp'),
    fs = require('fs'),
    argx = require('argx'),
    objnest = require('objnest');

/** @lends apemanTaskContribMkdir */
function apemanTaskContribMkdir(dirnames, options) {
    var args = argx(arguments);
    dirnames = [].concat(args.shift('string|array') || []);
    options = objnest.expand(args.pop('object') || {});
    return function task(context, callback) {
        var logger = context.logger;

        _rejectExisting(dirnames, function (dirnames) {
            async.eachSeries(dirnames, function (dirname, callback) {
                mkdirp(dirname, function (err) {
                    if (!err) {
                        logger.debug('Directory generated: ' + dirname);
                    }
                    callback(err);
                });
            }, callback);
        });
    }
}

function _rejectExisting(dirnames, callback) {
    async.reject(dirnames, fs.exists, callback);
}


module.exports = apemanTaskContribMkdir;
